eprllib.Agents.AgentSpec — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Agents.AgentSpec

## Agent Spec

This module implement the base for an agent specification to safe configuration of the object.

Classes

`ActionSpec`([actuators, action_fn, ...]) | ActionSpec is the base class for an action specification to safe configuration of the object.
`AgentSpec`([observation, action, reward]) | AgentSpec is the base class for an agent specification to safe configuration of the object.
`ObservationSpec`([variables, ...]) | ObservationSpec is the base class for an observation specification to safe configuration of the object.
`RewardSpec`([reward_fn, reward_fn_config]) | RewardSpec is the base class for an reward specification to safe configuration of the object.